"""

"""

from enum import Enum, auto

from sqlalchemy import Column, Integer, String, ForeignKey
from sqlalchemy.orm import relationship
from sqlalchemy.ext.declarative import declarative_base

Base = declarative_base()

def get_or_create(session, model, **kwargs):
    instance = session.query(model).filter_by(**kwargs).first()
    if instance:
        return instance
    else:
        instance = model(**kwargs)
        session.add(instance)
        session.commit()
        return instance


class ServerChannels(Base):
    __tablename__ = 'server_channels'

    id = Column(Integer, primary_key=True, autoincrement=True)
    server_id = Column(Integer, nullable=False)
    channel_id = Column(Integer, nullable=False)
    news_category_id = Column(Integer, nullable=False)
    active = Column(Integer, nullable=False, default=True)
    news_articles = relationship('NewsArticles', cascade='all, delete')


class NewsArticles(Base):
    __tablename__ = 'news_articles'

    id = Column(Integer, primary_key=True, autoincrement=True)
    url = Column(String, nullable=False)
    server_channel_id = Column(Integer, ForeignKey('server_channels.id'), nullable=False)


class NewsCategories(Base):
    __tablename__ = 'news_categories'

    id = Column(Integer, primary_key=True, autoincrement=True)
    name = Column(String, unique=True, nullable=False)


class DefaultNewsCategories(Enum):
    """

    """

    ALL = auto()
    WORLD = auto()
    UK = auto()
    NORTH_AMERICA = auto()
    ENTERTAINMENT = auto()
    BUSINESS = auto()
    TECH = auto()
    SCIENCE = auto()
    TOP_STORIES = auto()
